/*
 * pdsrvglobal.h
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */

/** \file pdsrvglobal.h
 *  \author Fernando Pujaico Rivera
 *  \date 01-04-2011
 *  \brief Variables globales y definciones de la biblioteca pdsrv
 *  
 *  <br><br>Aquí Estarán definidas las variables globales que serán usadas en
 *  toda la biblioteca pdsrv.
 */

#ifndef __PDSRVGLOBAL_H__
#define __PDSRVGLOBAL_H__

#include <stdio.h>

#ifdef __cplusplus
extern "C" {
#endif 


#ifndef TRUE
	#define TRUE 1
#endif

#ifndef FALSE
	#define FALSE 0
#endif

/** \defgroup PdsRvGlobalGroup Variables globales de la biblioteca PdsRv.
 * @{
 */

/*! Defino como variable real a un tipo float. Se puede usar cualquiera de los
 *  dos formas (PdsRvReal o float), su creación y uso, fue y es exclusivo por 
 *  facilidad en la reutilización y de portabilidad del código.
 *  \ingroup PdsRvGlobalGroup
 */
typedef float PdsRvReal;

/*! Defino como variable real de doble precisión a un tipo double. Se puede usar cualquiera de los
 *  dos formas (PdsRvReal o double), su creación y uso, fue y es exclusivo por 
 *  facilidad en la reutilización y de portabilidad del código.
 *  \ingroup PdsRvGlobalGroup
 */
typedef double PdsRvRealD;

/*! Defino como variable entera a un tipo int. Se puede usar cualquiera de los
 *  dos formas (PdsRvInteger o int), su creación y uso, fue y es exclusivo por
 *  facilidad en la reutilización y de portabilidad del código.
 *  \ingroup PdsRvGlobalGroup
 */
typedef int PdsRvInteger;

/*! Defino como variable entera positiva incluyendo cero con doble precisión a 
 *  un tipo unsigned long. Se puede usar cualquiera de los dos formas 
 *  (PdsRvNaturalD o unsigned long), su creación y uso, fue y es exclusivo por
 *  facilidad en la reutilización y de portabilidad del código.
 *  \ingroup PdsRvGlobalGroup
 */
typedef unsigned long PdsRvNaturalD;

/*! Defino como variable entera positiva incluyendo cero de 8 bits.
 *  Se puede usar cualquiera de los dos formas (PdsRvByte o unsigned char), su 
 *  creación y uso, fue y es exclusivo por facilidad en la reutilización y de 
 *  portabilidad del código.
 *  \ingroup PdsRvGlobalGroup
 */
typedef unsigned char PdsRvByte;

/**
 * @}
 */


#ifdef __cplusplus
}
#endif 

#endif /* __PDSRVGLOBAL_H__ */ 

