/*
 * testpdsrv2.c
 * 
 * Copyright 2011 Fernando Pujaico Rivera <fernando.pujaico.rivera@gmail.com>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 * 
 */

/** \file testpdsrv2.c
 *  \author Fernando Pujaico Rivera
 *  \date 18-04-2011
 *  \brief Programa para el testeo de los límites numéricos de las variables aleatorias.
 *
 *  \n\n Este programa verifica que las variables aleatorias no alcancen sus 
 *  valores límites, por ejemplo que no devuelvan infinito.
 *  Genero PDS_RAND_MAX+1 valores de las variables aleatorias, que es la 
 *  totalidad de valores distintos posibles. El programa comprueba que no existan
 *  infinitos en los valores devueltos.
 */

#include <config.h>
#include <stdlib.h>
#include <pds/pdsrv.h>


int main(int argc, char** argv)
{
	unsigned long i;
	PdsUniform	*X1=NULL;
	PdsGaussian	*X2=NULL;
	PdsRayleigh	*X3=NULL;
	PdsRvReal	x1;
	PdsRvReal	x2;
	PdsRvReal	x3;

	X1=pds_uniform_new(0.0,1.0);
	printf("Uniform(0.0,1.0): No debe contener 1.0: Debe contener 0.0\n");
	for(i=0;i<=(PDS_RAND_MAX+1);i++)
	{
		pds_uniform_get_value(X1,&x1);
		if(x1==0.0)	printf("Encontrado 0.0\n");
		if(x1==1.0)	printf("Encontrado 1.0:%11.9e:%10lu:%10lu\n",x1,PDS_RAND_MAX,X1->X1->x0);

		if(i%(PDS_RAND_MAX/100)==0)	printf("%2d%c\n",(int)(i*100.0/PDS_RAND_MAX),'%');
	}
	pds_uniform_free(X1);
	printf("\n");


	X2=pds_gaussian_new(0.0,1.0);
	printf("Gauss(0.0,1.0):No debe contener infinitos: Debe contener 0.0\n");
	for(i=0;i<=(PDS_RAND_MAX+1);i++)
	{
		pds_gaussian_get_value(X2,&x2);
		if(X2->X1->x0<4UL)			printf("Encontrado   cero:%11.9e\t[x0=%10lu/%10lu]\n",x2,X2->X1->x0,PDS_RAND_MAX);
		if(X2->X1->x0>(PDS_RAND_MAX-4UL))	printf("Encontrado Máximo:%11.9e\t[x0=%10lu/%10lu]\n",x2,X2->X1->x0,PDS_RAND_MAX);

		if(i%(PDS_RAND_MAX/100)==0)	printf("%2d%c\n",(int)(i*100.0/PDS_RAND_MAX),'%');
	}
	pds_gaussian_free(X2);
	printf("\n");


	X3=pds_rayleigh_new(1.0);
	printf("Rayleigh(1.0):No debe contener infinitos: Debe contener 0.0\n");
	for(i=0;i<=(PDS_RAND_MAX+1);i++)
	{
		pds_rayleigh_get_value(X3,&x3);
		if(X3->X1->x0<4UL)			printf("Encontrado   cero:%11.9e\t[x0=%10lu/%10lu]\n",x3,X3->X1->x0,PDS_RAND_MAX);
		if(X3->X1->x0>(PDS_RAND_MAX-4UL))	printf("Encontrado Máximo:%11.9e\t[x0=%10lu/%10lu]\n",x3,X3->X1->x0,PDS_RAND_MAX);

		if(i%(PDS_RAND_MAX/100)==0)	printf("%2d%c\n",(int)(i*100.0/PDS_RAND_MAX),'%');
	}
	pds_rayleigh_free(X3);
	printf("\n");



	return EXIT_SUCCESS;
}


